==> hellosign-java-sdk-3.3.3-sources.jar: com/hellosign/sdk/resource/Team.java <==
package com.hellosign.sdk.resource;

/**
 * The MIT License (MIT)
 * 
 * Copyright (C) 2015 hellosign.com
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import java.util.List;

import org.json.JSONObject;

import com.hellosign.sdk.HelloSignException;

public class Team extends AbstractResource {

    public static final String TEAM_KEY = "team";
    public static final String TEAM_NAME = "name";
    public static final String TEAM_ACCOUNTS = "accounts";
    public static final String TEAM_INVITEES = "invited_accounts";

    public Team() {
        super();
    }

    public Team(JSONObject json) throws HelloSignException {
        super(json, TEAM_KEY);
    }

    public String getName() {
        return getString(TEAM_NAME);
    }

    public List<Account> getAccounts() {
        return getList(Account.class, TEAM_ACCOUNTS);
    }

    public List<Account> getInvitedAccounts() {
        return getList(Account.class, TEAM_INVITEES);
    }
}

==> hellosign-java-sdk-4.0.12-sources.jar: com/hellosign/sdk/resource/Team.java <==
package com.hellosign.sdk.resource;

/**
 * The MIT License (MIT)
 * 
 * Copyright (C) 2015 hellosign.com
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import java.util.List;

import org.json.JSONObject;

import com.hellosign.sdk.HelloSignException;

public class Team extends AbstractResource {

    public static final String TEAM_KEY = "team";
    public static final String TEAM_NAME = "name";
    public static final String TEAM_ACCOUNTS = "accounts";
    public static final String TEAM_INVITEES = "invited_accounts";

    public Team() {
        super();
    }

    public Team(JSONObject json) throws HelloSignException {
        super(json, TEAM_KEY);
    }

    public String getName() {
        return getString(TEAM_NAME);
    }

    public List<Account> getAccounts() {
        return getList(Account.class, TEAM_ACCOUNTS);
    }

    public List<Account> getInvitedAccounts() {
        return getList(Account.class, TEAM_INVITEES);
    }
}
